DateFormatterPro extension

on

Methods

toDDMMMMYYYY() String

Available on DateTime, provided by the DateFormatterPro extension

Formats the DateTime object to a string in the format dd MMMM, yyyy.
toMMDDYYYY() String

Available on DateTime, provided by the DateFormatterPro extension

Formats the DateTime object to a string in the format MM/dd/yyyy.
toYYYYMMDD() String

Available on DateTime, provided by the DateFormatterPro extension

Formats the DateTime object to a string in the format yyyy-MM-dd.